#
# kubernetes kube-apiserver config
#

KUBE_INSECURE_API_ADDRESS="--insecure-bind-address=127.0.0.1"
KUBE_SECURE_API_PORT="--secure-port={{ kubernetes_api_port }}"
KUBE_ETCD_SERVERS="--etcd_servers=http://127.0.0.1:2379"
KUBE_SERVICE_ADDRESSES="--service-cluster-ip-range={{ kubernetes_srv_addr }}"
KUBE_ADMISSION_CONTROL="{{ kubernetes_admission }}"
KUBE_CLUSTER_ADVERTISE="--advertise-address={{ api_server_ip }}"
KUBE_TLS_CERT="--tls-cert-file=/etc/kubernetes/certs/kube_apiserver.crt"
KUBE_PRIVATE_KEY="--tls-private-key-file=/etc/kubernetes/certs/kube_apiserver.key"
KUBE_CLIENT_CA="--client-ca-file=/etc/kubernetes/certs/opendc-ca.crt"
KUBE_TOKEN_AUTH="--token-auth-file=/etc/kubernetes/tokens/known_tokens.csv"
KUBE_BASIC_AUTH="--basic-auth-file=/etc/kubernetes/users/known_users.csv"
KUBE_SERVICE_ACCOUNT_KEY="--service-account-key-file=/etc/kubernetes/certs/kube_apiserver.key"
KUBE_API_ARGS="--runtime-config=batch/v2alpha1=true"
#--authorization-mode=RBAC"
